summaryrefslogtreecommitdiffstats
path: root/src/likeback.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/likeback.h')
-rw-r--r--src/likeback.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/likeback.h b/src/likeback.h
index 1f1b684..c3d1f25 100644
--- a/src/likeback.h
+++ b/src/likeback.h
@@ -23,7 +23,7 @@
#include <tqobject.h>
-class KConfig;
+class TDEConfig;
class TDEAboutData;
class KAction;
class KActionCollection;
@@ -124,7 +124,7 @@ class LikeBack : public TQObject
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
* and to send with the comment, so you can filter per version and know if a comment refers the latest version of the application or not.
*/
- LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const TDEAboutData *aboutData = 0);
+ LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, TDEConfig *config = 0, const TDEAboutData *aboutData = 0);
/**
* Destructor.
@@ -330,10 +330,10 @@ class LikeBack : public TQObject
const TDEAboutData *aboutData();
/**
* @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
* @See The LikeBack constructor for more information.
*/
- KConfig *config();
+ TDEConfig *config();
/**
* During the first comment sending, the user is invited to enter his email address for the developers to be able to contact him back.
@@ -330,10 +330,10 @@ class LikeBack : public TQObject
const TDEAboutData *aboutData();
/**
- * @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
+ * @Returns A pointer to the TDEConfig used to store user configuration (email address, if the button-bar should be shown).
* @See The LikeBack constructor for more information.
*/